/**
 * Recursively traverses the specification and applies the transform function to each node.
 * The one from @scalar/openapi-parser does not support recursion.
 */
export async function traverse(specification, transform, path = [], seen = new WeakSet()) {
    const result = {};
    if (typeof specification !== 'object' || specification === null) {
        return specification;
    }
    if (seen.has(specification)) {
        return specification;
    }
    if (Array.isArray(specification)) {
        return Promise.all(specification.map((item, index) => traverse(item, transform, [...path, index.toString()], seen)));
    }
    const keys = Object.keys(specification);
    await Promise.all(keys.map(async (key) => {
        const value = specification[key];
        result[key] = await traverse(value, transform, [...path, key], seen);
    }));
    return transform(result, path);
}
